@@ -78,19 +78,13 @@ capitalize_words <- function(words, lowercase_of = TRUE) {
   }
 
   words <- tolower(words)
-  words <- strsplit(words, " ")
-  words <- lapply(words, upper_first_letter)
-  words <- unlist(lapply(words, paste, collapse = " "))
 
 
-  words <- strsplit(words, "-")
-  words <- lapply(words, upper_first_letter)
-  words <- unlist(lapply(words, paste, collapse = "-"))
-
-
-  words <- strsplit(words, "'")
-  words <- lapply(words, upper_first_letter)
-  words <- unlist(lapply(words, paste, collapse = "'"))
+  for (i in c(" ", "-", "#", "$", "%", "&", '\\(', ")", "-", "_", "=", "/", "@")) {
+    words <- strsplit(words, i)
+    words <- lapply(words, upper_first_letter)
+    words <- unlist(lapply(words, paste, collapse = i))
+  }
 
   if (lowercase_of) {
     words <- gsub(" Of ", " of ", words)
