@@ -26,7 +26,11 @@
 #' @export
 #'
 #' @examples
-make_latex_tables <- function(data,
+#' \dontrun{
+#' make_latex_tables(mtcars, file =  "text.tex", caption = "This is a description of the table",
+#' label = "internal_table_label", footnote = "Here is some info you should know to read this table")
+#' }
+  make_latex_tables <- function(data,
                               file,
                               caption = "",
                               label = "",
@@ -47,6 +51,7 @@ make_latex_tables <- function(data,
 
   writeLines("\\clearpage")
   writeLines(paste0("\\begin{", table_direction, "}[H]"))
+  writeLines("\renewcommand{\arraystretch}{1.15}")
   writeLines("\\centering")
   writeLines(paste0("\\caption{", caption, "}"))
   writeLines("\\begin{subtable}[c]{.6\\linewidth}")
